Models class

Constructors

Models({BorderRadius? borderRadius, List<Color>? colors, double? angle})

Properties

angle double?
final
borderRadius BorderRadius?
final
colors List<Color>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited