WalkTextForm class

Inheritance

Constructors

WalkTextForm({bool cheak = false, EdgeInsetsGeometry? paddingText, Key? key, double? height, double? width, Widget? child, Duration? duration, BorderRadius? borderRadius, List<double>? steps, List<Color>? colors, double? thicken, Curve? curve, double? angle, bool? reverse, TileMode? tileMode, Alignment? alignment, InputDecoration? decoration, required TextEditingController? controller, TextInputType? keyboardType, TextCapitalization? textCapitalization, TextInputAction? textInputAction, TextStyle? style, StrutStyle? strutStyle, TextAlign? textAlign, TextAlignVertical? textAlignVertical, bool? autofocus = false, bool? readOnly = false, bool? showCursor, int? maxLength, bool? enableInteractiveSelection = true, GestureTapCallback? onTap, FormFieldValidator<String>? validator, FormFieldSetter<String>? onSaved, ValueChanged<String>? onChanged, ValueChanged<String>? onFieldSubmitted, bool? enabled, ScrollPhysics? scrollPhysics, ScrollController? scrollController, required FocusNode? focusNode, bool? autovalidate = false, EdgeInsets? scrollPadding = const EdgeInsets.all(20.0), bool? enableSuggestions = true, bool? autocorrect = true, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool? enableSuggestionsOnUserInteraction = true, void onEditingComplete()?, InputCounterWidgetBuilder? buildCounter, Iterable<String>? autofillHints, Widget contextMenuBuilder(BuildContext, EditableTextState)?, Color? cursorColor, double? cursorHeight, Radius? cursorRadius, double cursorWidth = 2.0, bool enableIMEPersonalizedLearning = true, TextMagnifierConfiguration? magnifierConfiguration, MaxLengthEnforcement? maxLengthEnforcement, int? maxLines = 1, int? minLines, String? restorationId, bool expands = false, String? initialValue, List<TextInputFormatter>? inputFormatters, Brightness? keyboardAppearance, MouseCursor? mouseCursor, bool obscureText = false, String obscuringCharacter = '•', void onTapOutside(PointerDownEvent)?, TextSelectionControls? selectionControls, Mode? mode, SpellCheckConfiguration? spellCheckConfiguration, TextDirection? textDirection})

Properties

alignment Alignment?
final
angle double?
final
autocorrect bool?
final
autofillHints Iterable<String>?
final
autofocus bool?
final
autovalidate bool?
final
borderRadius BorderRadius?
final
buildCounter InputCounterWidgetBuilder?
final
cheak bool
getter/setter pair
child Widget?
final
colors List<Color>?
final
contextMenuBuilder Widget Function(BuildContext, EditableTextState)?
final
controller TextEditingController?
final
cursorColor Color?
final
cursorHeight double?
final
cursorRadius Radius?
final
cursorWidth double
final
curve Curve?
final
decoration InputDecoration?
final
duration Duration?
final
enabled bool?
final
enableIMEPersonalizedLearning bool
final
enableInteractiveSelection bool?
final
enableSuggestions bool?
final
enableSuggestionsOnUserInteraction bool?
final
expands bool
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
initialValue String?
final
inputFormatters List<TextInputFormatter>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance Brightness?
final
keyboardType TextInputType?
final
magnifierConfiguration TextMagnifierConfiguration?
final
maxLength int?
final
maxLengthEnforcement MaxLengthEnforcement?
final
maxLines int?
final
minLines int?
final
mode Mode?
final
mouseCursor MouseCursor?
final
obscureText bool
final
obscuringCharacter String
final
onChanged ValueChanged<String>?
final
onEditingComplete → void Function()?
final
onFieldSubmitted ValueChanged<String>?
final
onSaved FormFieldSetter<String>?
final
onTap GestureTapCallback?
final
onTapOutside → void Function(PointerDownEvent)?
final
paddingText EdgeInsetsGeometry?
final
readOnly bool?
final
restorationId String?
final
reverse bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
final
scrollPadding EdgeInsets?
final
scrollPhysics ScrollPhysics?
final
selectionControls TextSelectionControls?
final
showCursor bool?
final
smartDashesType SmartDashesType?
final
smartQuotesType SmartQuotesType?
final
spellCheckConfiguration SpellCheckConfiguration?
final
steps List<double>?
final
strutStyle StrutStyle?
final
style TextStyle?
final
textAlign TextAlign?
final
textAlignVertical TextAlignVertical?
final
textCapitalization TextCapitalization?
final
textDirection TextDirection?
final
textInputAction TextInputAction?
final
thicken double?
final
tileMode TileMode?
final
validator FormFieldValidator<String>?
final
width double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _WalkTextFormState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited